@@ -36,7 +36,7 @@ __all__ =  [
 #
 LIBRARY_PROPERTIES = {
     'library': 'Python amqplib',
-    'library_version': '0.6',
+    'library_version': '0.6.1',
     }
 
 AMQP_LOGGER = logging.getLogger('amqplib')
@@ -148,15 +148,10 @@ class Connection(AbstractChannel):
             # we were redirected, close the socket, loop and try again
             try:
                 self.close()
-            except:
+            except Exception:
                 pass
 
 
-    def __del__(self):
-        if self.transport is not None:
-            self.close()
-
-
     def _do_close(self):
         self.transport.close()
         self.transport = None
@@ -165,6 +160,8 @@ class Connection(AbstractChannel):
         for ch in temp_list:
             ch._do_close()
 
+        self.connection = self.channels = None
+
 
     def _get_free_channel_id(self):
         for i in xrange(1, self.channel_max+1):
@@ -290,6 +287,10 @@ class Connection(AbstractChannel):
                 is the ID of the method.
 
         """
+        if self.transport is None:
+            # already closed
+            return
+
         args = AMQPWriter()
         args.write_short(reply_code)
         args.write_shortstr(reply_text)
